==> PubChemR_0.99-1.tar.gz: PubChemR/R/get_synonyms.R <==
#' Retrieve Synonyms from PubChem
#'
#' This function sends a request to PubChem to retrieve synonyms for a given identifier.
#' It returns a list of synonyms corresponding to the provided identifier.
#'
#' @param identifier A character or numeric value specifying the identifier for the request.
#' @param namespace A character string specifying the namespace for the request. Default is 'cid'.
#' @param domain A character string specifying the domain for the request. Default is 'compound'.
#' @param searchtype A character string specifying the search type. Default is NULL.
#' @param ... Additional arguments passed to \code{\link{get_json}}.
#'
#' @return A list where each element corresponds to the synonyms retrieved from PubChem for the provided identifier.
#'         The names of the list elements are based on the provided identifier.
#'
#' @importFrom RJSONIO fromJSON
#' @export
#'
#' @examples
#' get_synonyms(
#'   identifier = "aspirin",
#'   namespace = "name"
#' )
get_synonyms <- function(identifier, namespace = 'cid', domain = 'compound', searchtype = NULL, ...) {

  # Try to get the response and parse JSON
  result <- tryCatch({
    # Assuming 'get_json' is a function you've previously defined, similar to your Python environment
    response_json <- get_json(identifier, namespace, domain, 'synonyms', searchtype, ...)

    # Check if the response contains the expected information
    if (!is.null(response_json) && !is.null(response_json$InformationList) && !is.null(response_json$InformationList$Information)) {
      response_json$InformationList$Information
    } else {
      return(list())  # Return an empty list if the expected content is not found
    }
  }, error = function(e) {
    message(paste("An error occurred:", e$message))  # Log the error message
    return(list())  # Return an empty list in case of an error
  })

  return(result)
}

==> PubChemR_1.2.tar.gz: PubChemR/R/get_synonyms.R <==
#' Retrieve Synonyms from PubChem
#'
#' This function sends a request to PubChem to retrieve synonyms for a given identifier.
#' It returns a list of synonyms corresponding to the provided identifier.
#'
#' @param identifier A character or numeric value specifying the identifier for the request.
#' @param namespace A character string specifying the namespace for the request. Default is 'cid'.
#' @param domain A character string specifying the domain for the request. Default is 'compound'.
#' @param searchtype A character string specifying the search type. Default is NULL.
#' @param options Additional arguments passed to \code{\link{get_json}}.
#'
#' @return A list where each element corresponds to the synonyms retrieved from PubChem for the provided identifier.
#'         The names of the list elements are based on the provided identifier.
#'
#' @importFrom RJSONIO fromJSON
#' @export
#'
#' @examples
#' get_synonyms(
#'   identifier = "aspirin",
#'   namespace = "name"
#' )
get_synonyms <- function(identifier, namespace = 'cid', domain = 'compound', searchtype = NULL, options = NULL) {

  # Try to get the response and parse JSON
  result <- tryCatch({
    # Assuming 'get_json' is a function you've previously defined, similar to your Python environment
    response_json <- get_json(identifier, namespace, domain, 'synonyms', searchtype, options)

    # Check if the response contains the expected information
    if (!is.null(response_json) && !is.null(response_json$InformationList) && !is.null(response_json$InformationList$Information)) {
      response_json$InformationList$Information
    } else {
      return(list())  # Return an empty list if the expected content is not found
    }
  }, error = function(e) {
    message(paste("An error occurred:", e$message))  # Log the error message
    return(list())  # Return an empty list in case of an error
  })

  return(result)
}
